package com.wyz.demo.service.impl;

import com.wyz.demo.dao.OrderRepository;
import com.wyz.demo.dao.UserRepository;
import com.wyz.demo.dto.OrderDTO;
import com.wyz.demo.po.OrderPO;
import com.wyz.demo.service.OrderService;
import com.wyz.demo.vo.OrderVO;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpSession;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class OrderServiceImpl implements OrderService {


    @Autowired
    private UserRepository userRepository;

    @Autowired
    private OrderRepository orderRepository;

    /**
     * 获取全部订单 - 根据用户名
     * @Param username 用户名
     */
    @Override
    public List<OrderVO> getAll(String username) {
        int sender_id = userRepository.getIdByUsername(username);
        List<OrderPO> orders = orderRepository.getOrders(sender_id);


        List<OrderVO> res = new ArrayList<>();
        for (OrderPO orderPO : orders) {
            OrderVO orderVO = new OrderVO();

            orderVO.setTimestamp(orderPO.getTimestamp());
            orderVO.setDescription(orderPO.getDescription());
            orderVO.setPrice(orderPO.getPrice());
            String receiver = userRepository.getUsernameById(orderPO.getReceiverId());
//            log.info("receiver-id:{}",orderPO.getReceiverId());
//            log.info("receiver:{}",receiver);
            orderVO.setReceiver(receiver);
            orderVO.setStatus(orderPO.getStatus());

            res.add(orderVO);
        }


        return res;
    }

    @Override
    public void addOrder(OrderDTO orderDTO, HttpSession sess) {

        OrderPO orderPO = new OrderPO();

        orderPO.setDescription(orderDTO.getDescription());
        orderPO.setWhen(orderDTO.getWhen());
        orderPO.setLocation(orderDTO.getLocation());
        orderPO.setSenderId(userRepository.getIdByUsername((String)sess.getAttribute("username")));
        orderPO.setPrice(orderDTO.getPrice());
        orderPO.setComment(orderDTO.getComment());

        orderRepository.addOrder(orderPO);
    }
}
